@@ -9,22 +9,28 @@ from jotdx import __version__
 from jotdx import logger
 from jotdx import server
 from jotdx.affair import Affair
-from jotdx.logger import log
 from jotdx.quotes import Quotes
 from jotdx.reader import Reader
 from jotdx.utils import get_config_path
 from jotdx.utils import to_file
 
 
+# @click.group()
+# @click.option('--debug/--no-debug', default=False)
+# @click.pass_context
+# def cli(ctx, debug):
+#     ctx.obj['DEBUG'] = debug
+#     ctx.obj['DEBUG'] and logging.basicConfig(level=logging.DEBUG)
+
 @click.group()
-@click.option('--debug/--no-debug', default=False)
-@click.pass_context
-def cli(ctx, debug):
-    ctx.obj['DEBUG'] = debug
-    ctx.obj['DEBUG'] and logging.basicConfig(level=logging.DEBUG)
+@click.version_option(__version__, '-V', '--version', prog_name='Mootdx', message='%(prog)s: v%(version)s')
+@click.help_option('-h', '--help')
+def entry():
+    ...
 
 
-@cli.command(help='读取股票在线行情数据.')
+@entry.command(help='读取股票在线行情数据.')
+@click.help_option('-h', '--help')
 @click.option('-o', '--output', default=None, help='输出文件, 支持CSV, HDF5, Excel等格式.')
 @click.option('-s', '--symbol', default='600000', help='股票代码.')
 @click.option('-a', '--action', default='bars', help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).', )
@@ -50,7 +56,8 @@ def quotes(symbol, action, market, output):
         raise e
 
 
-@cli.command(help='读取股票本地行情数据.')
+@entry.command(help='读取股票本地行情数据.')
+@click.help_option('-h', '--help')
 @click.option('-d', '--tdxdir', default='C:/new_tdx', help='通达信数据目录.')
 @click.option('-s', '--symbol', default='600000', help='股票代码.')
 @click.option('-a', '--action', default='daily', help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).')
@@ -67,26 +74,28 @@ def reader(symbol, action, market, tdxdir, output):
         raise e
 
 
-@cli.command(help='测试行情服务器.')
+@entry.command(help='测试行情服务器.')
+@click.help_option('-h', '--help')
 @click.option('-l', '--limit', default=5, help='显示最快前几个，默认 5.')
-@click.option('-v', '--verbose', is_flag=True, help='详细模式')
+@click.option('-v', '--verbose', count=True, help='详细模式')
 def bestip(limit, verbose):
-    verbose and logger.getLogger(verbose=verbose)
+    logger.reset(verbose=verbose)
     config = get_config_path('config.json')
     server.bestip(limit=limit, console=True, sync=False)
-    log.success('[√] 已经将最优服务器IP写入配置文件 {}'.format(config))
+    logger.logger.success('[√] 已经将最优服务器IP写入配置文件 {}'.format(config))
 
 
-@cli.command(help='财务文件下载&解析.')
+@entry.command(help='财务文件下载&解析.')
+@click.help_option('-h', '--help')
 @click.option('-p', '--parse', default=None, help='要解析文件名')
 @click.option('-f', '--fetch', default=None, help='下载财务文件的文件名')
 @click.option('-a', '--downall', is_flag=True, help='下载全部文件')
 @click.option('-o', '--output', default=None, help='输出文件, 支持 CSV, HDF5, Excel, JSON 等格式.')
 @click.option('-d', '--downdir', default='output', help='下载文件目录')
 @click.option('-l', '--listfile', is_flag=True, default=False, help='显示全部文件')
-@click.option('-v', '--verbose', is_flag=True, help='详细模式')
+@click.option('-v', '--verbose', count=True, help='详细模式')
 def affair(parse, fetch, downdir, output, downall, verbose, listfile):
-    verbose and logger.getLogger(verbose=verbose)
+    logger.reset(verbose=verbose)
 
     files = Affair.files()
 
@@ -124,15 +133,11 @@ def affair(parse, fetch, downdir, output, downall, verbose, listfile):
             output and to_file(feed, output)
             click.echo(feed)
         else:
-            log.error('没找到要解析的文件.')
+            logger.logger.error('没找到要解析的文件.')
 
 
-@cli.command(help='显示当前软件版本.')
-def version():
-    click.echo('mootdx v{}'.format(__version__))
-
-
-@cli.command(help='批量下载行情数据.')
+@entry.command(help='批量下载行情数据.')
+@click.help_option('-h', '--help')
 @click.option('-o', '--output', default='bundle', help='转存文件目录.')
 @click.option('-s', '--symbol', default='600000', help='股票代码. 多个用,隔开')
 @click.option('-a', '--action', default='bars', help='操作类型 (daily: 日线, minute: 一分钟线, fzline: 五分钟线).')
@@ -166,9 +171,5 @@ def bundle(symbol, action, market, output, extension):
     click.echo('[√] 下载文件到 "{}"'.format(os.path.realpath(output)))
 
 
-def entry():
-    cli(obj={})
-
-
 if __name__ == '__main__':
     entry()
